@@ -638,8 +638,10 @@ class rr():
             await db.execute("DELETE FROM rr WHERE guild = ? and msg_id = ?", (guild,x))
         await db.commit()
         await db.close()
+        message_id = ", ".join(message_id)
         await ctx.send(f"Delted reaction role info for {message_id}", delete_after=7)
     async def display(ctx, dir):
+        limit = False
         os.chdir(dir)
         guild = str(ctx.guild.id)
         db = await aiosqlite.connect("rr.db")
@@ -650,6 +652,7 @@ class rr():
                 number += 1
                 async with db.execute("SELECT role,emoji,channel,msg_id FROM rr WHERE guild = ? and msg_id = ?", (guild,entry[0])) as f:
                     msg = ""
+                    msg_limit = ""
                     async for entry in f:
                         role,emoji,channel,msg_id = entry
                         channel = ctx.guild.get_channel(int(channel))
@@ -662,10 +665,19 @@ class rr():
                             channel = channel.mention
                         except:
                             channel = "#deleted-channel"
-                        msg += f"Emoji: {emoji} Role: {role} Channel: {channel} Message ID: {msg_id}\n"
-                embed.add_field(name=f"Reaction Role #{number}", inline=False, value=msg)
+                            msg += f"Emoji: {emoji} Role: {role} Channel: {channel} Message ID: {msg_id}\n"
+                            msg_limit += f"Channel: {channel} Message ID: {msg_id}\n"
+                if len(msg) > 1010:
+                    embed.add_field(name=f"Reaction Role #{number}", inline=False, value=msg_limit)
+                    limit = True
+                else:
+                    embed.add_field(name=f"Reaction Role #{number}", inline=False, value=msg)
         if number > 0:
-            embed.set_footer(text=f"Total Reaction Roles | {number}")
+            if limit == False:
+                embed.set_footer(text=f"Total Reaction Roles | {number}")
+            else:
+                embed.set_footer(text=f"Total Reaction Roles | {number}")
+                await ctx.reply("One of your reaction roles went over the Discord limit. It will still work perfectly but only essintial data will be displayed in this command to save space.", delete_after=10)
             await ctx.send(embed=embed, reference= ctx.message.reference or ctx.message)
         else:
             await ctx.send("There are no reaction roles in this server.", delete_after=5)
